@@ -17,18 +17,22 @@
 #include <llvm/Support/Path.h>
 
 using namespace clang;
-using namespace llvm;
 
 namespace ccls {
 std::string pathFromFileEntry(const FileEntry &file) {
-  // If getName() refers to a file within a workspace folder, we prefer it
-  // (which may be a symlink).
-  std::string ret = normalizePath(file.getName());
+  std::string ret;
+  if (file.getName().startswith("/../")) {
+    // Resolve symlinks outside of working folders. This handles leading path
+    // components, e.g. (/lib -> /usr/lib) in
+    // /../lib/gcc/x86_64-linux-gnu/10/../../../../include/c++/10/utility
+    ret = file.tryGetRealPathName();
+  } else {
+    // If getName() refers to a file within a workspace folder, we prefer it
+    // (which may be a symlink).
+    ret = normalizePath(file.getName());
+  }
   if (normalizeFolder(ret))
     return ret;
-  // Resolve symlinks outside of working folders. This handles leading path
-  // components, e.g. (/lib -> /usr/lib) in
-  // /../lib/gcc/x86_64-linux-gnu/10/../../../../include/c++/10/utility
   ret = realPath(ret);
   normalizeFolder(ret);
   return ret;
