@@ -109,10 +109,8 @@ void ReplyOnce::replyLocationLink(std::vector<LocationLink> &result) {
   if (g_config->client.linkSupport) {
     (*this)(result);
   } else {
-    std::vector<Location> result1;
-    for (auto &loc : result)
-      result1.emplace_back(std::move(loc));
-    (*this)(result1);
+    (*this)(std::vector<Location>(std::make_move_iterator(result.begin()),
+                                  std::make_move_iterator(result.end())));
   }
 }
 
@@ -254,9 +252,9 @@ QueryFile *MessageHandler::findFile(const std::string &path, int *out_file_id) {
 
 std::pair<QueryFile *, WorkingFile *>
 MessageHandler::findOrFail(const std::string &path, ReplyOnce &reply,
-                           int *out_file_id) {
+                           int *out_file_id, bool allow_unopened) {
   WorkingFile *wf = wfiles->getFile(path);
-  if (!wf) {
+  if (!wf && !allow_unopened) {
     reply.notOpened(path);
     return {nullptr, nullptr};
   }
