@@ -12,6 +12,7 @@
 #include "working_files.hh"
 
 #include <llvm/ADT/Twine.h>
+#include <llvm/Config/llvm-config.h>
 #include <llvm/Support/Threading.h>
 
 #include <rapidjson/document.h>
@@ -221,8 +222,13 @@ REFLECT_STRUCT(InitializeParam, rootUri, capabilities, trace, workspaceFolders);
 
 struct InitializeResult {
   ServerCap capabilities;
+  struct ServerInfo {
+    const char *name = "ccls";
+    const char *version = CCLS_VERSION;
+  } serverInfo;
 };
-REFLECT_STRUCT(InitializeResult, capabilities);
+REFLECT_STRUCT(InitializeResult::ServerInfo, name, version);
+REFLECT_STRUCT(InitializeResult, capabilities, serverInfo);
 
 struct FileSystemWatcher {
   std::string globPattern = "**/*";
@@ -250,6 +256,12 @@ void *indexer(void *arg_) {
   delete arg;
   std::string name = "indexer" + std::to_string(idx);
   set_thread_name(name.c_str());
+  // Don't lower priority on __APPLE__. getpriority(2) says "When setting a
+  // thread into background state the scheduling priority is set to lowest
+  // value, disk and network IO are throttled."
+#if LLVM_ENABLE_THREADS && LLVM_VERSION_MAJOR >= 9 && !defined(__APPLE__)
+  set_thread_priority(ThreadPriority::Background);
+#endif
   pipeline::indexer_Main(h->manager, h->vfs, h->project, h->wfiles);
   pipeline::threadLeave();
   return nullptr;
@@ -307,6 +319,9 @@ void do_initialize(MessageHandler *m, InitializeParam &param,
   didChangeWatchedFiles =
       capabilities.workspace.didChangeWatchedFiles.dynamicRegistration;
 
+  if (!g_config->client.snippetSupport)
+    g_config->completion.duplicateOptional = false;
+
   // Ensure there is a resource directory.
   if (g_config->clang.resourceDir.empty())
     g_config->clang.resourceDir = getDefaultResourceDirectory();
@@ -333,17 +348,16 @@ void do_initialize(MessageHandler *m, InitializeParam &param,
     std::string path = wf.uri.getPath();
     ensureEndsInSlash(path);
     std::string real = realPath(path) + '/';
-    workspaceFolders.emplace_back(path, path == real ? "" : real);
+    workspaceFolders.emplace_back(path, real);
   }
   if (workspaceFolders.empty()) {
     std::string real = realPath(project_path) + '/';
-    workspaceFolders.emplace_back(project_path,
-                                  project_path == real ? "" : real);
+    workspaceFolders.emplace_back(project_path, real);
   }
   std::sort(workspaceFolders.begin(), workspaceFolders.end(),
             [](auto &l, auto &r) { return l.first.size() > r.first.size(); });
   for (auto &[folder, real] : workspaceFolders)
-    if (real.empty())
+    if (real == folder)
       LOG_S(INFO) << "workspace folder: " << folder;
     else
       LOG_S(INFO) << "workspace folder: " << folder << " -> " << real;
@@ -367,7 +381,7 @@ void do_initialize(MessageHandler *m, InitializeParam &param,
   // may take a long time. Indexer threads will emit status/progress
   // reports.
   if (g_config->index.threads == 0)
-    g_config->index.threads = std::thread::hardware_concurrency();
+    g_config->index.threads = (int)std::thread::hardware_concurrency();
 
   LOG_S(INFO) << "start " << g_config->index.threads << " indexers";
   for (int i = 0; i < g_config->index.threads; i++)
