@@ -1,17 +1,5 @@
-/* Copyright 2017-2018 ccls Authors
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================*/
+// Copyright 2017-2018 ccls Authors
+// SPDX-License-Identifier: Apache-2.0
 
 #include "query.hh"
 
@@ -135,7 +123,7 @@ IndexUpdate IndexUpdate::createDelta(IndexFile *previous, IndexFile *current) {
     previous = &empty;
   r.lid2path = std::move(current->lid2path);
 
-  r.funcs_hint = current->usr2func.size() - previous->usr2func.size();
+  r.funcs_hint = int(current->usr2func.size() - previous->usr2func.size());
   for (auto &it : previous->usr2func) {
     auto &func = it.second;
     if (func.def.detailed_name[0])
@@ -153,7 +141,7 @@ IndexUpdate IndexUpdate::createDelta(IndexFile *previous, IndexFile *current) {
     r.funcs_derived[func.usr].second = std::move(func.derived);
   }
 
-  r.types_hint = current->usr2type.size() - previous->usr2type.size();
+  r.types_hint = int(current->usr2type.size() - previous->usr2type.size());
   for (auto &it : previous->usr2type) {
     auto &type = it.second;
     if (type.def.detailed_name[0])
@@ -173,7 +161,7 @@ IndexUpdate IndexUpdate::createDelta(IndexFile *previous, IndexFile *current) {
     r.types_instances[type.usr].second = std::move(type.instances);
   };
 
-  r.vars_hint = current->usr2var.size() - previous->usr2var.size();
+  r.vars_hint = int(current->usr2var.size() - previous->usr2var.size());
   for (auto &it : previous->usr2var) {
     auto &var = it.second;
     if (var.def.detailed_name[0])
