@@ -350,14 +350,19 @@ void buildPreamble(Session &session, CompilerInvocation &ci,
   std::string content = session.wfiles->getContent(task.path);
   std::unique_ptr<llvm::MemoryBuffer> buf =
       llvm::MemoryBuffer::getMemBuffer(content);
-#if LLVM_VERSION_MAJOR >= 12 // llvmorg-12-init-11522-g4c55c3b66de
+#if LLVM_VERSION_MAJOR >= 12
+  // llvmorg-12-init-11522-g4c55c3b66de
   auto bounds = ComputePreambleBounds(*ci.getLangOpts(), *buf, 0);
+  // llvmorg-12-init-17739-gf4d02fbe418d
+  if (!task.from_diag && oldP &&
+      oldP->preamble.CanReuse(ci, *buf, bounds, *fs))
+    return;
 #else
   auto bounds = ComputePreambleBounds(*ci.getLangOpts(), buf.get(), 0);
-#endif
   if (!task.from_diag && oldP &&
       oldP->preamble.CanReuse(ci, buf.get(), bounds, fs.get()))
     return;
+#endif
   // -Werror makes warnings issued as errors, which stops parsing
   // prematurely because of -ferror-limit=. This also works around the issue
   // of -Werror + -Wunused-parameter in interaction with SkipFunctionBodies.
@@ -556,6 +561,10 @@ void *diagnosticMain(void *manager_) {
     std::shared_ptr<PreambleData> preamble = session->getPreamble();
     IntrusiveRefCntPtr<llvm::vfs::FileSystem> fs =
         preamble ? preamble->stat_cache->consumer(session->fs) : session->fs;
+    std::unique_ptr<CompilerInvocation> ci =
+        buildCompilerInvocation(task.path, session->file.args, fs);
+    if (!ci)
+      continue;
     if (preamble) {
       bool rebuild = false;
       {
@@ -567,16 +576,25 @@ void *diagnosticMain(void *manager_) {
             rebuild = true;
           }
       }
+      if (!rebuild) {
+        std::string content = manager->wfiles->getContent(task.path);
+        auto buf = llvm::MemoryBuffer::getMemBuffer(content);
+#if LLVM_VERSION_MAJOR >= 12 // llvmorg-12-init-11522-g4c55c3b66de
+        PreambleBounds bounds =
+            ComputePreambleBounds(*ci->getLangOpts(), *buf, 0);
+#else
+        PreambleBounds bounds =
+            ComputePreambleBounds(*ci->getLangOpts(), buf.get(), 0);
+#endif
+        if (bounds.Size != preamble->preamble.getBounds().Size)
+          rebuild = true;
+      }
       if (rebuild) {
         manager->preamble_tasks.pushBack({task.path, nullptr, true}, true);
         continue;
       }
     }
 
-    std::unique_ptr<CompilerInvocation> ci =
-        buildCompilerInvocation(task.path, session->file.args, fs);
-    if (!ci)
-      continue;
     // If main file is a header, add -Wno-unused-function
     if (lookupExtension(session->file.filename).second)
       ci->getDiagnosticOpts().Warnings.push_back("no-unused-function");
